@@ -6,6 +6,9 @@ class Widget( BSCTModelMixin, models.Model ):
     name = models.CharField( max_length = 10 )
     sku  = models.IntegerField()
 
+    def sku_detail( self ):
+        return 'SKU_%d' % ( self.sku )
+
     def __unicode__( self ):
         return '%s' % ( self.name )
     
